@@ -42,7 +42,7 @@ class ManualControlScraper(BaseScraper):
                  link_priority=None, ignore_links=None, only_links=None,
                  ignore_extensions=None, result_page_links=None,
                  form_submit_natural_click=False, form_submit_wait=5,
-                 force_page_wait=None,
+                 force_page_wait=None, form_submit_button_selector=None,
                  load_images=False, show_browser=False, warc_index_file=None,
                  warc_directory=None, return_data=False, page_timeout=None,
                  backend="selenium"):
@@ -51,12 +51,13 @@ class ManualControlScraper(BaseScraper):
             loglevel=loglevel, stdout=stdout
         )
         if page_timeout is not None:
-            page_timeout = int(page_timeout)
+            page_timeout = int(page_timeout or 0)
         # set up web scraper controller
         self.control = Controller(
             leave_host=leave_host, driver=driver, remote_hub=remote_hub,
             form_submit_natural_click=form_submit_natural_click,
             form_submit_wait=int(form_submit_wait or 0),
+            form_submit_button_selector=form_submit_button_selector,
             force_page_wait=int(force_page_wait or 0),
             load_images=load_images, show_browser=show_browser,
             warc_index_file=warc_index_file, warc_directory=warc_directory,
@@ -65,9 +66,9 @@ class ManualControlScraper(BaseScraper):
         )
         self.control.initialize(baseurl)
         # depth of DFS in search of form
-        self.maxdepth = int(maxdepth)
+        self.maxdepth = int(maxdepth or 0)
         # current depth of iterating through 'next' form buttons
-        self.formdepth = int(formdepth)
+        self.formdepth = int(formdepth or 0)
         # max total pages to fetch
         self.max_pages = int(max_pages) if max_pages else None
         # keep number of fetched pages here.
@@ -107,7 +108,7 @@ class ManualControlScraper(BaseScraper):
         # attempt a position-based "natural click" over the element
         self.form_submit_natural_click = form_submit_natural_click
         # a period of seconds to force a wait after a submit
-        self.form_submit_wait = int(form_submit_wait)
+        self.form_submit_wait = int(form_submit_wait or 0)
         # a generator, outputting individual form interaction plans
         if input:
             self.input_gen = InputParser(input).generate()
@@ -154,7 +155,6 @@ class ManualControlScraper(BaseScraper):
                 logger.debug("[*] Max 'next' formdepth reached %s" % depth)
                 break
 
-            found_next = False
             button_data = self.control.vectorizer.button_vectors()
             n_buttons = len(button_data)
             logger.info("[.] On result page %s" % (depth + 1))
@@ -162,36 +162,50 @@ class ManualControlScraper(BaseScraper):
                 n_buttons, button_data
             ))
 
-            # save the initial landing data page
-            self.save_training_page(classname="data_pages")
-            self.save_screenshot(classname="data_pages")
-
             if self.result_page_links:
                 self.click_until_no_links(self.result_page_links)
 
+            # element type, index, text
+            next_found = None
             for ix in range(n_buttons):
-                button = button_data[ix]
-                logger.debug(" - Checking button: %s" % button)
-                if not self.next_match:
-                    continue
-                if re.findall(self.next_match.lower(), button.lower()):
-                    logger.info("[.] Next button found! Clicking: %s" % (
-                        button
-                    ))
-                    depth += 1
-                    self.control.select_button(ix, iterating_form=True)
-                    # subsequent page loads get saved here
-                    self.save_training_page(classname="data_pages")
-                    self.save_screenshot(classname="data_pages")
-
-                    found_next = True
-                    # don't click any other next buttons
+                button_text = button_data[ix]
+                logger.debug(" - Checking button: %s" % button_text)
+                if re.findall(self.next_match.lower(), button_text.lower()):
+                    next_found = ("button", ix, button_text)
                     break
 
-            if not found_next:
+            if not next_found:
+                link_vectors = self.control.vectorizer.link_vectors()
+                n_clickable = len(link_vectors)
+                logger.debug(" - Button not found, searching %s links" % (
+                    n_clickable
+                ))
+                for ix in range(n_clickable):
+                    link_text = link_vectors[ix]
+                    logger.debug(" - Checking clickable: %s" % link_text)
+                    if re.findall(self.next_match.lower(), link_text.lower()):
+                        next_found = ("link", ix, link_text)
+                        break
+
+            # we didn't find a next match, break loop
+            if next_found is None:
                 logger.debug(" - Next button not found!")
                 break
+            else:
+                ntype, ix, text = next_found
+                logger.info("[.] Next button found! Clicking: %s" % (text))
+                depth += 1
+                if ntype == "button":
+                    self.control.select_button(ix, iterating_form=True)
+                elif ntype == "link":
+                    self.control.select_link(ix, iterating_form=True)
 
+                # subsequent page loads get saved here
+                self.save_training_page(classname="data_pages")
+                self.save_screenshot(classname="data_pages")
+
+            # check for infinite loop, this is based on the hash
+            # of the previous few pages
             logger.debug(" - Checking for infinite loop...")
             if self.control.scraper.infinite_loop_detected:
                 logger.debug(" - Infinte loop detected. Breaking.")
@@ -203,6 +217,9 @@ class ManualControlScraper(BaseScraper):
 
     def scrape(self, depth=0):
         logger.info("[.] Crawl depth %s" % depth)
+        logger.info(" - Total pages: %s of max: %s" % (
+            self.total_pages, self.max_pages
+        ))
         if self.maxdepth != -1 and depth > self.maxdepth:
             logger.info(" - Maximum depth %s reached, returning..." % depth)
             self.control.back()
@@ -288,11 +305,21 @@ class ManualControlScraper(BaseScraper):
                             ix, input_index, radio_index
                         )
 
+                # capture post-input screenshot
                 self.save_screenshot(classname="interaction_pages")
+
+                # actually submit the page
                 self.control.submit(ix)
                 self.total_pages += 1
-                self.save_screenshot(classname="interaction_pages")
-                self.keep_clicking_next_btns()
+
+                # save the initial landing result page
+                self.save_screenshot(classname="data_pages")
+                self.save_training_page(classname="data_pages")
+
+                # if we're looking for next buttons, click them
+                if self.next_match:
+                    self.keep_clicking_next_btns()
+
                 self.scraped = True
                 self.control.back()
 
